package com.ruoyi.iit.mapper;

import java.util.List;
import com.ruoyi.iit.domain.IitFilePush;

/**
 * 推送管理Mapper接口
 *
 * @author Hao Li
 * @date 2025-04-11
 */
public interface IitFilePushMapper
{
    /**
     * 查询推送管理
     *
     * @param id 推送管理主键
     * @return 推送管理
     */
    public IitFilePush selectIitFilePushById(Long id);

    /**
     * 查询推送管理列表
     *
     * @param iitFilePush 推送管理
     * @return 推送管理集合
     */
    public List<IitFilePush> selectIitFilePushList(IitFilePush iitFilePush);

    /**
     * 新增推送管理
     *
     * @param iitFilePush 推送管理
     * @return 结果
     */
    public int insertIitFilePush(IitFilePush iitFilePush);

    /**
     * 修改推送管理
     *
     * @param iitFilePush 推送管理
     * @return 结果
     */
    public int updateIitFilePush(IitFilePush iitFilePush);

    /**
     * 删除推送管理
     *
     * @param id 推送管理主键
     * @return 结果
     */
    public int deleteIitFilePushById(Long id);

    /**
     * 批量删除推送管理
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteIitFilePushByIds(Long[] ids);
}
