package com.ruoyi.web.controller.iit;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.iit.domain.IitFilePush;
import com.ruoyi.iit.service.IIitFilePushService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 推送管理Controller
 *
 * @author Hao Li
 * @date 2025-04-11
 */
@RestController
@RequestMapping("/iit/push")
public class IitFilePushController extends BaseController
{
    @Autowired
    private IIitFilePushService iitFilePushService;

    /**
     * 查询推送管理列表
     */
    @PreAuthorize("@ss.hasPermi('iit:push:list')")
    @GetMapping("/list")
    public TableDataInfo list(IitFilePush iitFilePush)
    {
        startPage();
        List<IitFilePush> list = iitFilePushService.selectIitFilePushList(iitFilePush);
        return getDataTable(list);
    }

    /**
     * 导出推送管理列表
     */
    @PreAuthorize("@ss.hasPermi('iit:push:export')")
    @Log(title = "推送管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, IitFilePush iitFilePush)
    {
        List<IitFilePush> list = iitFilePushService.selectIitFilePushList(iitFilePush);
        ExcelUtil<IitFilePush> util = new ExcelUtil<IitFilePush>(IitFilePush.class);
        util.exportExcel(response, list, "推送管理数据");
    }

    /**
     * 获取推送管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('iit:push:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(iitFilePushService.selectIitFilePushById(id));
    }

    /**
     * 新增推送管理
     */
    @PreAuthorize("@ss.hasPermi('iit:push:add')")
    @Log(title = "推送管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody IitFilePush iitFilePush)
    {
        return toAjax(iitFilePushService.insertIitFilePush(iitFilePush));
    }

    /**
     * 修改推送管理
     */
    @PreAuthorize("@ss.hasPermi('iit:push:edit')")
    @Log(title = "推送管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody IitFilePush iitFilePush)
    {
        return toAjax(iitFilePushService.updateIitFilePush(iitFilePush));
    }

    /**
     * 删除推送管理
     */
    @PreAuthorize("@ss.hasPermi('iit:push:remove')")
    @Log(title = "推送管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(iitFilePushService.deleteIitFilePushByIds(ids));
    }
}
